@@ -6,8 +6,11 @@
 #include <numpy/arrayobject.h>
 #include <numpy/ufuncobject.h>
 
-static PyObject *PyExc_ITAPSError;
-static PyTypeObject iBaseEntity_Type;
+static PyTypeObject iBaseArr_Type;
+
+static PyObject *
+PyArray_NewFromOutBase(int,npy_intp *,int,iBase_OutArray *,iBase_Object *);
+
 
 static PyTypeObject iBase_Type = {
     PyObject_HEAD_INIT(NULL)
@@ -34,22 +37,58 @@ static PyTypeObject iBase_Type = {
     "iBase instance objects"                  /* tp_doc */
 };
 
-#define HANDLE_TYPE Entity
-#include "iBase_handleTempl.def"
-#undef HANDLE_TYPE
+subarray_t subtypes[16];
+static size_t counter = 0;
 
-#define HANDLE_TYPE EntitySet
-#include "iBase_handleTempl.def"
-#undef HANDLE_TYPE
+static void
+iBase_RegisterSubArray(int dtype,PyTypeObject *inst_type,PyTypeObject *el_type,
+                       arrgetfunc getter,arrcreatefunc creator)
+{
+    if(counter == sizeof(subtypes)/sizeof(subtypes[0]))
+        return;
+    subtypes[counter].dtype     = dtype;
+    subtypes[counter].inst_type = inst_type;
+    subtypes[counter].el_type   = el_type;
+    subtypes[counter].getter    = getter;
+    subtypes[counter].creator   = creator;
+    counter++;
+}
 
-#define HANDLE_TYPE Tag
-#include "iBase_handleTempl.def"
-#undef HANDLE_TYPE
+static subarray_t *
+get_sub_array(int dtype,PyObject *type)
+{
+    size_t i;
+    for(i=0; i<sizeof(subtypes)/sizeof(subtypes[0]); i++)
+    {
+        if(subtypes[i].dtype == dtype &&
+           subtypes[i].inst_type == (PyTypeObject*)type)
+            return &subtypes[i];
+    }
+    return NULL;
+}
 
 static int NPY_IBASEENT;
 static int NPY_IBASEENTSET;
 static int NPY_IBASETAG;
 
+#define HANDLE_TYPE Entity
+#define HANDLE_NPYTYPE NPY_IBASEENT
+#include "iBase_handleTempl.def"
+#undef HANDLE_TYPE
+#undef HANDLE_NPYTYPE
+
+#define HANDLE_TYPE EntitySet
+#define HANDLE_NPYTYPE NPY_IBASEENTSET
+#include "iBase_handleTempl.def"
+#undef HANDLE_TYPE
+#undef HANDLE_NPYTYPE
+
+#define HANDLE_TYPE Tag
+#define HANDLE_NPYTYPE NPY_IBASETAG
+#include "iBase_handleTempl.def"
+#undef HANDLE_TYPE
+#undef HANDLE_NPYTYPE
+
 ENUM_TYPE(iBaseType,           "iBase.Type",           "");
 ENUM_TYPE(iBaseAdjCost,        "iBase.AdjCost",        "");
 ENUM_TYPE(iBaseStorageOrder,   "iBase.StorageOrder",   "");
@@ -63,7 +102,6 @@ static void
 ArrDeallocObj_dealloc(ArrDealloc_Object *self)
 {
     free(self->memory);
-    Py_XDECREF(self->base);
 
     self->ob_type->tp_free((PyObject *)self);
 }
@@ -94,12 +132,10 @@ static PyTypeObject ArrDealloc_Type = {
 };
 
 static ArrDealloc_Object *
-ArrDealloc_New(PyObject *base, void *memory)
+ArrDealloc_New(void *memory)
 {
     ArrDealloc_Object *o = PyObject_New(ArrDealloc_Object,&ArrDealloc_Type);
     o->memory = memory;
-    o->base = base;
-    Py_XINCREF(base);
     return o;
 }
 
@@ -135,25 +171,58 @@ iBaseStorageOrder_Cvt(PyObject *object,int *val)
     return 1;
 }
 
-static char typechars[] = {'i','d','E','b'};
+static char typechars[] = {'b','i','d','E','S'};
+static PyTypeObject *types[] = {0,&PyInt_Type,0,&iBaseEntity_Type,
+                                &iBaseEntitySet_Type};
+static int typenums[] = {NPY_BYTE, NPY_INT, NPY_DOUBLE, 0 /* set below */, 
+                         0 /* set below */};
 
 static int
 iBaseTagType_Cvt(PyObject *object,int *val)
 {
     int i;
     char c;
-    if( !PyArg_Parse(object,"c",&c))
-        return 0;
+    PyArray_Descr *dtype;
 
-    for(i=0; i<sizeof(typechars); i++)
+    /* first try matching type objects directly, if we have overrides */
+    for(i=0; i<sizeof(types)/sizeof(types[0]); i++)
     {
-        if(typechars[i] == c)
+        if(types[i] && PyObject_RichCompareBool((PyObject*)types[i],object,
+                                                Py_EQ))
         {
             *val = i;
             return 1;
         }
     }
 
+    /* now try matching type chars */
+    if(PyArg_Parse(object,"c",&c))
+    {
+        for(i=0; i<sizeof(typechars); i++)
+        {
+            if(typechars[i] == c)
+            {
+                *val = i;
+                return 1;
+            }
+        }
+    }
+    PyErr_Clear();
+
+    /* finally, try grabbing a NumPy dtype and checking with that */
+    if(PyArray_DescrConverter(object,&dtype))
+    {
+        for(i=0; i<sizeof(typenums)/sizeof(typenums[0]); i++)
+        {
+            if(typenums[i] == dtype->type_num)
+            {
+                *val = i;
+                return 1;
+            }
+        }
+        Py_DECREF(dtype);
+    }
+
     PyErr_SetString(PyExc_ValueError,ERR_TYPE_CODE);
     return 0;
 }
@@ -164,16 +233,79 @@ iBaseTagType_ToChar(enum iBase_TagValueType t)
     return typechars[t];
 }
 
+static int
+iBaseTagType_ToTypenum(enum iBase_TagValueType t)
+{
+    return typenums[t];
+}
+
+static int iBaseBuffer_Cvt(PyObject *obj,iBase_OutArray *arr)
+{
+    PyArray_Chunk chunk;
+    if(!PyArray_BufferConverter(obj,&chunk))
+        return 0;
+
+    arr->base = chunk.base;
+    arr->data = chunk.ptr;
+    arr->alloc = chunk.len;
+
+    return 1;
+}
+
+#include "numpy_extensions.h"
+
+static PyObject *
+register_exception(PyObject *m,const char *name,PyObject *base)
+{
+    char full_name[256];
+    snprintf(full_name,256,"iBase.%s",name);
+
+    PyObject *exc = PyErr_NewException(full_name,base,0);
+    if(exc == NULL)
+        return NULL;
+
+    Py_INCREF(exc);
+    PyModule_AddObject(m,name,exc);
+    return exc;
+}
+
 PyMODINIT_FUNC initiBase(void)
 {
-    PyArray_Descr *descr;
     PyObject *m = Py_InitModule("iBase",module_methods);
     import_array();
     import_ufunc();
 
-    PyExc_ITAPSError = PyErr_NewException("iBase.ITAPSError",0,0);
-    Py_INCREF(PyExc_ITAPSError);
-    PyModule_AddObject(m,"ITAPSError",PyExc_ITAPSError);
+    PyObject *PyExc_ITAPSError = register_exception(m,"ITAPSError",NULL);
+
+    const char *exc_names[] = {
+        "MeshAlreadyLoadedError",
+        "NoMeshDataError",
+        "FileNotFoundError",
+        "FileWriteError",
+        "NilArrayError",
+        "ArraySizeError",
+        "ArrayDimensionError",
+        "EntityHandleError",
+        "EntityCountError",
+        "EntityTypeError",
+        "EntityTopologyError",
+        "TypeAndTopoError",
+        "EntityCreationError",
+        "TagHandleError",
+        "TagNotFoundError",
+        "TagAlreadyExistsError",
+        "TagInUseError",
+        "EntitySetHandleError",
+        "IteratorHandleError",
+        "ArgumentError",
+        "MemoryAllocationError",
+        "NotSupportedError",
+        "UnknownError",
+    };
+    static PyObject *PyExc_Errors[iBase_FAILURE];
+    int i;
+    for(i=0; i<iBase_FAILURE; i++)
+        PyExc_Errors[i] = register_exception(m,exc_names[i],PyExc_ITAPSError);
 
     ArrDealloc_Type.tp_new = PyType_GenericNew;
     if (PyType_Ready(&ArrDealloc_Type) < 0)
@@ -182,24 +314,33 @@ PyMODINIT_FUNC initiBase(void)
     /***** register C API *****/
     static void *IBase_API[] = {
         NULL, /* PyExc_ITAPSError */
+        NULL, /* PyExc_Errors */
         &ArrDealloc_Type,
         &ArrDealloc_New,
         &iBase_Type,
         &iBaseEntity_Type,
         &iBaseEntitySet_Type,
         &iBaseTag_Type,
+        &iBaseEntity_FromHandle,
+        &iBaseEntitySet_FromHandle,
+        &iBaseTag_FromHandle,
+        &iBaseEntity_GetHandle,
+        &iBaseEntitySet_GetHandle,
+        &iBaseTag_GetHandle,
         &NPY_IBASEENT,
         &NPY_IBASEENTSET,
         &NPY_IBASETAG,
-        &iBaseEntityArr_equal,
-        &iBaseEntitySetArr_equal,
-        &iBaseTagArr_equal,
         &iBaseType_Cvt,
         &iBaseStorageOrder_Cvt,
         &iBaseTagType_Cvt,
+        &iBaseBuffer_Cvt,
         &iBaseTagType_ToChar,
+        &iBaseTagType_ToTypenum,
+        &iBase_RegisterSubArray,
+        &PyArray_NewFromOutBase,
     };
     IBase_API[0] = PyExc_ITAPSError;
+    IBase_API[1] = PyExc_Errors;
     PyObject *api_obj;
 
     /* Create a CObject containing the API pointer array's address */
@@ -208,11 +349,11 @@ PyMODINIT_FUNC initiBase(void)
     if(api_obj != NULL)
         PyModule_AddObject(m, "_C_API", api_obj);
 
-    /***** acquire "equal" ufunc *****/
+    /***** acquire "equal"/"not_equal" ufuncs *****/
     PyObject *ops = PyArray_GetNumericOps();
-    PyUFuncObject *ufunc = (PyUFuncObject*)PyDict_GetItemString(ops,"equal");
+    PyUFuncObject *eq  = (PyUFuncObject*)PyDict_GetItemString(ops,"equal");
+    PyUFuncObject *neq = (PyUFuncObject*)PyDict_GetItemString(ops,"not_equal");
     Py_DECREF(ops);
-    int types[3];
 
     REGISTER_CLASS(m,"Base",iBase);
 
@@ -251,57 +392,25 @@ PyMODINIT_FUNC initiBase(void)
     ADD_ENUM(iBaseCreationStatus,"failed",     iBase_CREATION_FAILED);
 
     /***** initialize handles *****/
-    REGISTER_CLASS(m,"Entity",iBaseEntity);
-    REGISTER_CLASS(m,"EntitySet",iBaseEntitySet);
-    REGISTER_CLASS(m,"Tag",iBaseTag);
+    REGISTER_CLASS_BASE(m,"Entity",    iBaseEntity,    PyGenericArrType);
+    REGISTER_CLASS_BASE(m,"EntitySet", iBaseEntitySet, PyGenericArrType);
+    REGISTER_CLASS_BASE(m,"Tag",       iBaseTag,       PyGenericArrType);
 
-    /***** initialize iBaseEntity array type *****/
-    descr = PyArray_DescrNewFromType(NPY_INTP);
-    descr->f = &iBaseEntityArr_funcs;
+    iBaseEntity_RegisterArray   ('j',eq,neq);
+    iBaseEntitySet_RegisterArray('J',eq,neq);
+    iBaseTag_RegisterArray      ('T',eq,neq);
 
-    descr->typeobj = &iBaseEntity_Type;
-    descr->kind = 'V';
-    descr->type = 'j';
-    descr->hasobject = NPY_USE_GETITEM|NPY_USE_SETITEM;
-    descr->elsize = sizeof(iBase_EntityHandle);
+    typenums[3] = NPY_IBASEENT;
+    typenums[4] = NPY_IBASEENTSET;
 
-    NPY_IBASEENT = PyArray_RegisterDataType(descr);
-    PyModule_AddObject(m,"npy_ent",(PyObject*)descr);
+    /* PyArray_Type's tp_alloc/tp_free are sucky */
+    iBaseArr_Type.tp_alloc = PyType_GenericAlloc;
+    iBaseArr_Type.tp_free  = _PyObject_Del;
+    REGISTER_CLASS_BASE(m,"Array",iBaseArr,PyArray);
 
-    types[0] = types[1] = NPY_IBASEENT; types[2] = NPY_BOOL;
-    PyUFunc_RegisterLoopForType(ufunc,NPY_IBASEENT,iBaseEntityArr_equal,types,
-                                0);
-
-    /***** initialize iBaseEntitySet array type *****/
-    descr = PyArray_DescrNewFromType(NPY_INTP);
-    descr->f = &iBaseEntitySetArr_funcs;
-
-    descr->typeobj = &iBaseEntitySet_Type;
-    descr->kind = 'V';
-    descr->type = 'J';
-    descr->hasobject = NPY_USE_GETITEM|NPY_USE_SETITEM;
-    descr->elsize = sizeof(iBase_EntitySetHandle);
-
-    NPY_IBASEENTSET = PyArray_RegisterDataType(descr);
-    PyModule_AddObject(m,"npy_entset",(PyObject*)descr);
-
-    types[0] = types[1] = NPY_IBASEENTSET; types[2] = NPY_BOOL;
-    PyUFunc_RegisterLoopForType(ufunc,NPY_IBASEENTSET,iBaseEntitySetArr_equal,
-                                types,0);
-
-    /***** initialize iBaseTag array type *****/
-    descr = PyArray_DescrNewFromType(NPY_INTP);
-    descr->f = &iBaseTagArr_funcs;
-
-    descr->typeobj = &iBaseTag_Type;
-    descr->kind = 'V';
-    descr->type = 'T';
-    descr->hasobject = NPY_USE_GETITEM|NPY_USE_SETITEM;
-    descr->elsize = sizeof(iBase_TagHandle);
-
-    NPY_IBASETAG = PyArray_RegisterDataType(descr);
-    PyModule_AddObject(m,"npy_tag",(PyObject*)descr);
-
-    types[0] = types[1] = NPY_IBASETAG; types[2] = NPY_BOOL;
-    PyUFunc_RegisterLoopForType(ufunc,NPY_IBASETAG,iBaseTagArr_equal,types,0);
+    /* eliminate warnings */
+    (void)PyArray_TryFromObject;
+    (void)PyArray_ToVectors;
 }
+
+#include "iBase_array.inl"
