@@ -13,6 +13,7 @@ typedef struct
 {
     PyObject_HEAD
     iMesh_Instance handle;
+    int owned;
 } iMesh_Object;
 
 #define iMesh_Check(o)                                 \
@@ -25,8 +26,8 @@ typedef struct
     int is_arr;
     union
     {
-        iMesh_EntityIterator    one;
-        iMesh_EntityArrIterator arr;
+        iBase_EntityIterator    one;
+        iBase_EntityArrIterator arr;
     } iter;
 } iMeshIter_Object;
 
@@ -36,13 +37,13 @@ typedef struct
     iMesh_Object *instance;
 } iMeshEntitySet_Object;
 
-#define iMeshEntitySet_NewRaw()                         \
-    PyObject_New(iMeshEntitySet_Object,&iMeshEntitySet_Type)
+#define iMeshEntitySet_New()                            \
+    PyObject_AllocNew(iMeshEntitySet_Object,&iMeshEntitySet_Type)
 
 #define iMeshEntitySet_Check(o)                         \
     PyObject_TypeCheck((PyObject*)(o),&iMeshEntitySet_Type)
 
-#define iMeshEntitySet_GetInstance(o)                   \
+#define iMeshEntitySet_GET_INSTANCE(o)                  \
     ( ((iMeshEntitySet_Object*)(o))->instance )
 
 typedef struct
@@ -51,15 +52,19 @@ typedef struct
     iMesh_Object *instance;
 } iMeshTag_Object;
 
-#define iMeshTag_NewRaw()                               \
-    PyObject_New(iMeshTag_Object,&iMeshTag_Type)
+#define iMeshTag_New()                                  \
+    PyObject_AllocNew(iMeshTag_Object,&iMeshTag_Type)
 
 #define iMeshTag_Check(o)                               \
     PyObject_TypeCheck((PyObject*)(o),&iMeshTag_Type)
 
-#define iMeshTag_GetInstance(o)                         \
+#define iMeshTag_GET_INSTANCE(o)                        \
     ( ((iMeshTag_Object*)(o))->instance )
 
+typedef PyObject * (*meshfrominstfunc)(iMesh_Instance);
+typedef PyObject * (*meshfromsetfunc)(iMesh_Object *,iBase_EntitySetHandle);
+typedef PyObject * (*meshfromtagfunc)(iMesh_Object *,iBase_TagHandle);
+typedef iMesh_Object * (*meshgetinstfunc)(PyObject *);
 
 #ifndef _IMESH_MODULE
 
@@ -75,18 +80,18 @@ void **IMesh_API;
 static void **IMesh_API = NULL;
 #endif
 
-#define iMesh_Type          (*(PyTypeObject*)    IMesh_API[0])
-#define iMeshIter_Type      (*(PyTypeObject*)    IMesh_API[1])
-#define iMeshEntitySet_Type (*(PyTypeObject*)    IMesh_API[2])
-#define iMeshTag_Type       (*(PyTypeObject*)    IMesh_API[3])
-#define NPY_IMESHENTSET     (*(int*)             IMesh_API[4])
-#define NPY_IMESHTAG        (*(int*)             IMesh_API[5])
-#define iMeshEntitySet_New  ( (iMeshEntitySet_Object * (*)     \
-                              (iMesh_Object *))  IMesh_API[6])
-#define iMeshTag_New        ( (iMeshTag_Object * (*)           \
-                              (iMesh_Object *))  IMesh_API[7])
-#define CreateEnt_Type      ( (PyObject*)        IMesh_API[8])
-#define iMeshTopology_cvt   ( (cvtfunc)          IMesh_API[9])
+#define iMesh_Type                 (*(PyTypeObject*)   IMesh_API[ 0])
+#define iMeshIter_Type             (*(PyTypeObject*)   IMesh_API[ 1])
+#define iMeshEntitySet_Type        (*(PyTypeObject*)   IMesh_API[ 2])
+#define iMeshTag_Type              (*(PyTypeObject*)   IMesh_API[ 3])
+#define iMesh_FromInstance         ( (meshfrominstfunc)IMesh_API[ 4])
+#define iMeshEntitySet_FromHandle  ( (meshfromsetfunc) IMesh_API[ 5])
+#define iMeshEntitySet_GetInstance ( (meshgetinstfunc) IMesh_API[ 6])
+#define iMeshTag_FromHandle        ( (meshfromtagfunc) IMesh_API[ 7])
+#define iMeshTag_GetInstance       ( (meshgetinstfunc) IMesh_API[ 8])
+#define CreateEnt_Type             (*(PyTypeObject*)   IMesh_API[ 9])
+#define AdjEntIndices_Type         (*(PyTypeObject*)   IMesh_API[10])
+#define iMeshTopology_Cvt          ( (cvtfunc)         IMesh_API[11])
 
 
 #if !defined(NO_IMPORT_IMESH) && !defined(NO_IMPORT)
