@@ -13,7 +13,7 @@ typedef struct
 {
     PyObject_HEAD
     iRel_Instance handle;
-    PyObject *refs;
+    int owned;
 } iRel_Object;
 
 #define iRel_Check(o)                                  \
@@ -22,23 +22,24 @@ typedef struct
 typedef struct
 {
     PyObject_HEAD
-    iRel_RelationHandle handle;
+    iRel_PairHandle handle;
     iRel_Object *instance;
     iBase_Object *related[2];
-} iRelRelation_Object;
+} iRelPair_Object;
 
-#define iRelRelation_NewRaw()                           \
-    PyObject_New(iRelRelation_Object,&iRelRelation_Type)
+#define iRelPair_New()                                  \
+    PyObject_New(iRelPair_Object,&iRelPair_Type)
 
-#define iRelRelation_Check(o)                           \
-    PyObject_TypeCheck((PyObject*)(o),&iRelRelation_Type)
+#define iRelPair_Check(o)                               \
+    PyObject_TypeCheck((PyObject*)(o),&iRelPair_Type)
 
-#define iRelRelation_GetInstance(o)                     \
-    ( ((iRelRelation_Object*)(o))->instance )
+#define iRelPair_GET_INSTANCE(o)                        \
+    ( ((iRelPair_Object*)(o))->instance )
 
-#define iRelRelation_GetHandle(o)                       \
-  ((iRelRelation_Object*)(o))->handle
+#define iRelPair_GET_HANDLE(o)                          \
+    ((iRelPair_Object*)(o))->handle
 
+typedef PyObject * (*relfrominstfunc)(iRel_Instance);
 
 #ifndef _IREL_MODULE
 
@@ -54,7 +55,9 @@ void **IRel_API;
 static void **IRel_API = NULL;
 #endif
 
-#define iRel_Type          (*(PyTypeObject*)IRel_API[0])
+#define iRel_Type         (*(PyTypeObject*)  IRel_API[0])
+#define iRelPair_Type     (*(PyTypeObject*)  IRel_API[1])
+#define iRel_FromInstance ( (relfrominstfunc)IRel_API[2])
 
 
 #if !defined(NO_IMPORT_IREL) && !defined(NO_IMPORT)
