@@ -1,4 +1,7 @@
 import sys
+if sys.hexversion >= 0x020600f0:
+    from collections import namedtuple
+
 
 def OffsetList(offsets, data):
     if isinstance(data, tuple):
@@ -9,10 +12,10 @@ def OffsetList(offsets, data):
 class OffsetListSingle(object):
     def __init__(self, offsets, data):
         self.offsets = offsets
-        self.raw = data
+        self.data = data
 
     def _mapify(self, i):
-        return self.raw[i]
+        return self.data[i]
 
     def __getitem__(self, key):
         if isinstance(key, tuple):
@@ -40,51 +43,35 @@ class OffsetListSingle(object):
 class OffsetListTuple(OffsetListSingle):
     if sys.hexversion >= 0x020600f0:
         def _mapify(self, i):
-            return self.raw.__class__._make([ val[i] for val in self.raw ])
+            return self.data.__class__._make([ val[i] for val in self.data ])
 
         def __getattr__(self, key):
-            return OffsetListSingle(self.offsets, getattr(self.raw, key))
+            return OffsetListSingle(self.offsets, getattr(self.data, key))
 
-        fields = property(lambda self: self.raw._fields)
+        fields = property(lambda self: self.data._fields)
 
         def slice(self, key):
             if isinstance(key, str):
-                return OffsetListSingle(self.offsets, getattr(self.raw, key))
+                return OffsetListSingle(self.offsets, getattr(self.data, key))
             else:
-                return OffsetListSingle(self.offsets, self.raw[key])
+                return OffsetListSingle(self.offsets, self.data[key])
     else:
         def _mapify(self, i):
-            return tuple([ val[i] for val in self.raw ])
+            return tuple([ val[i] for val in self.data ])
 
         def slice(self, key):
-            return OffsetListSingle(self.offsets, self.raw[key])
+            return OffsetListSingle(self.offsets, self.data[key])
 
-
-class IndexedOffsetList:
-    def __init__(self, entities, indices, offsets, raw):
-        self.entities = entities
-        self.indices = indices
-        self.offsets = offsets
-        self.raw = raw
+class IndexedList(object):
+    def __init__(self, offsets, indices, data):
+        self.indices = OffsetListSingle(offsets, indices)
+        self.data = data
 
     def __getitem__(self, key):
-        return self.raw[ self.index(key) ]
-
-    def index(self, key):
-        if isinstance(key, tuple):
-            if len(key) != 2:
-                raise ValueError
-            if key[1] < 0 or key[1] >= self.length(key[0]):
-                raise IndexError
-            return self.indices[ self.offsets[key[0]] + key[1] ]
-        else:
-            return self.indices[ self.offsets[key]:self.offsets[key+1] ]
+        return self.data[ self.indices[key] ]
 
     def length(self, i = None):
-        if i == None:
-            return len(self.offsets)-1
-        else:
-            return self.offsets[i+1] - self.offsets[i]
+        return self.indices.length(i)
 
     def __len__(self):
-        return self.length()
+        return len(self.indices)
