@@ -1,5 +1,5 @@
 from itaps import iBase, iGeom
-import unittest
+from .. import testhelper as unittest
 import numpy
 
 class TestCoords(unittest.TestCase):
@@ -340,26 +340,30 @@ class TestCoords(unittest.TestCase):
         faces = self.geom.getEntities(iBase.Type.face)
         edges = self.geom.getEntities(iBase.Type.edge)
 
-        range = self.geom.getEntRange(faces[0], iGeom.Basis.uv)
-        self.assert_((range == [[-1,-1], [1,1]]).all())
-        range = self.geom.getEntRange(faces[0])
-        self.assert_((range == [[-1,-1], [1,1]]).all())
+        lo, hi = self.geom.getEntRange(faces[0], iGeom.Basis.uv)
+        self.assert_((lo == [-1,-1]).all())
+        self.assert_((hi == [ 1, 1]).all())
+        lo, hi = self.geom.getEntRange(faces[0])
+        self.assert_((lo == [-1,-1]).all())
+        self.assert_((hi == [ 1, 1]).all())
 
-        range = self.geom.getEntRange(faces, iGeom.Basis.uv)
-        self.assert_((range == [[[-1,-1]]*6, [[1,1]]*6]).all())
-        range = self.geom.getEntRange(faces)
-        self.assert_((range == [[[-1,-1]]*6, [[1,1]]*6]).all())
+        lo, hi = self.geom.getEntRange(faces, iGeom.Basis.uv)
+        self.assert_((lo == [[-1,-1]]*6).all())
+        self.assert_((hi == [[ 1, 1]]*6).all())
+        lo, hi = self.geom.getEntRange(faces)
+        self.assert_((lo == [[-1,-1]]*6).all())
+        self.assert_((hi == [[ 1, 1]]*6).all())
 
-        range = self.geom.getEntRange(edges[0], iGeom.Basis.u)
-        self.assert_((range == [[-1], [1]]).all())
-        range = self.geom.getEntRange(edges[0])
-        self.assert_((range == [[-1], [1]]).all())
+        lo, hi = self.geom.getEntRange(edges[0], iGeom.Basis.u)
+        self.assert_((lo == [-1]).all())
+        self.assert_((hi == [ 1]).all())
+        lo, hi = self.geom.getEntRange(edges[0])
+        self.assert_((lo == [-1]).all())
+        self.assert_((hi == [ 1]).all())
 
-        range = self.geom.getEntRange(edges, iGeom.Basis.u)
-        self.assert_((range == [[[-1]]*12, [[1]]*12]).all())
-        range = self.geom.getEntRange(edges)
-        self.assert_((range == [[[-1]]*12, [[1]]*12]).all())
-
-
-if __name__ == '__main__':
-    unittest.main()
+        lo, hi = self.geom.getEntRange(edges, iGeom.Basis.u)
+        self.assert_((lo == [[-1]]*12).all())
+        self.assert_((hi == [[ 1]]*12).all())
+        lo, hi = self.geom.getEntRange(edges)
+        self.assert_((lo == [[-1]]*12).all())
+        self.assert_((hi == [[ 1]]*12).all())
