@@ -1,5 +1,5 @@
 from itaps import iBase, iGeom
-import unittest
+from .. import testhelper as unittest
 
 class TestEntSet(unittest.TestCase):
     def setUp(self):
@@ -13,17 +13,17 @@ class TestEntSet(unittest.TestCase):
     def testCreation(self):
         self.assertEqual(self.set.instance, self.geom)
         self.assertEqual(self.set.isList, True)
-        self.assertEqual(self.set.getNumEntSets(1), 0)
-        self.assertEqual(self.geom.getNumEntSets(0), 1)
-        self.assertEqual(self.geom.rootSet.getNumEntSets(0), 1)
+        self.assertEqual(self.set.getNumEntSets(), 0)
+        self.assertEqual(self.geom.getNumEntSets(), 1)
+        self.assertEqual(self.geom.rootSet.getNumEntSets(), 1)
 
-        sets = self.geom.getEntSets(0)
-        self.assert_((sets == self.geom.rootSet.getEntSets(0)).all())
+        sets = self.geom.getEntSets()
+        self.assertArray(sets, self.geom.rootSet.getEntSets())
         self.assertEqual(self.set, sets[0])
 
         self.geom.destroyEntSet(self.set)
-        self.assertEqual(self.geom.getNumEntSets(0), 0)
-        self.assertEqual(self.geom.rootSet.getNumEntSets(0), 0)
+        self.assertEqual(self.geom.getNumEntSets(), 0)
+        self.assertEqual(self.geom.rootSet.getNumEntSets(), 0)
 
     def testEnt(self):
         ent = self.geom.createBrick(1,1,1)
@@ -68,17 +68,32 @@ class TestEntSet(unittest.TestCase):
 
     def testEntSet(self):
         sub = self.geom.createEntSet(True)
+        subsub = self.geom.createEntSet(True)
 
         self.assertFalse(self.set.contains(sub))
-        self.assert_(sub not in self.set)
+        self.assertTrue(sub not in self.set)
+        self.assertEqual(self.set.getNumEntSets(), 0)
+        self.assertEqual(len(self.set.getEntSets()), 0)
 
         self.set.add(sub)
-        self.assert_(self.set.contains(sub))
-        self.assert_(sub in self.set)
+        sub.add(subsub)
+
+        self.assertTrue(self.set.contains(sub))
+        self.assertTrue(sub in self.set)
+        self.assertEqual(self.set.getNumEntSets(), 2)
+        self.assertEqual(self.set.getNumEntSets(0), 1)
+        self.assertEqual(self.set.getNumEntSets(1), 2)
+
+        self.assertArraySorted(self.set.getEntSets(),
+                               iBase.Array([sub, subsub]))
+        self.assertArraySorted(self.set.getEntSets(0), iBase.Array([sub]))
+        self.assertArraySorted(self.set.getEntSets(1),
+                               iBase.Array([sub, subsub]))
+
 
         self.set.remove(sub)
         self.assertFalse(self.set.contains(sub))
-        self.assert_(sub not in self.set)
+        self.assertTrue(sub not in self.set)
 
         self.geom.destroyEntSet(sub)
 
@@ -88,17 +103,17 @@ class TestEntSet(unittest.TestCase):
         return
 
         self.assert_(self.set.isChild(sub))
-        self.assertEqual(self.set.getNumChildren(1), 1)
-        self.assertEqual(sub.getNumParents(1),  1)
+        self.assertEqual(self.set.getNumChildren(), 1)
+        self.assertEqual(sub.getNumParents(),  1)
 
-        self.assertEqual(self.set.getChildren(1)[0], sub)
-        self.assertEqual(sub.getParents(1)[0], self.set)
+        self.assertEqual(self.set.getChildren()[0], sub)
+        self.assertEqual(sub.getParents()[0], self.set)
 
         self.set.removeChild(sub)
 
         self.assert_(not self.set.isChild(sub))
-        self.assertEqual(self.set.getNumChildren(1), 0)
-        self.assertEqual(sub.getNumParents(1), 0)
+        self.assertEqual(self.set.getNumChildren(), 0)
+        self.assertEqual(sub.getNumParents(), 0)
 
     def testSubtract(self):
         set2 = self.geom.createEntSet(True)
@@ -149,6 +164,3 @@ class TestEntSet(unittest.TestCase):
         union = self.set.union(set2)
         self.assertTrue(union.contains(ents[0]))
         self.assertTrue(union.contains(ents[1]))
-
-if __name__ == '__main__':
-    unittest.main()
