@@ -1,49 +1,47 @@
 from itaps import iBase, iMesh
-import unittest
+from .. import testhelper as unittest
 
 class TestEntSet(unittest.TestCase):
     def setUp(self):
         self.mesh = iMesh.Mesh()
         self.set = self.mesh.createEntSet(True)
 
-    def tearDown(self):
-        self.mesh = None
-
     def testCreation(self):
         self.assertEqual(self.set.instance, self.mesh)
         self.assertEqual(self.set.isList, True)
-        self.assertEqual(self.set.getNumEntSets(1), 0)
-        self.assertEqual(self.mesh.getNumEntSets(0), 1)
-        self.assertEqual(self.mesh.rootSet.getNumEntSets(0), 1)
 
-        sets = self.mesh.getEntSets(0)
-        self.assert_((sets == self.mesh.rootSet.getEntSets(0)).all())
+        self.assertEqual(self.set.getNumEntSets(), 0)
+        self.assertEqual(self.mesh.getNumEntSets(), 1)
+        self.assertEqual(self.mesh.rootSet.getNumEntSets(), 1)
+
+        sets = self.mesh.getEntSets()
+        self.assertArray(sets, self.mesh.rootSet.getEntSets())
         self.assertEqual(self.set, sets[0])
 
         self.mesh.destroyEntSet(self.set)
-        self.assertEqual(self.mesh.getNumEntSets(0), 0)
-        self.assertEqual(self.mesh.rootSet.getNumEntSets(0), 0)
+        self.assertEqual(self.mesh.getNumEntSets(), 0)
+        self.assertEqual(self.mesh.rootSet.getNumEntSets(), 0)
 
     def testEnt(self):
         ent = self.mesh.createVtx([1,2,3])
         self.assertEqual(self.mesh.getNumOfType(iBase.Type.all), 1)
         self.assertEqual(self.mesh.getNumOfTopo(iMesh.Topology.all), 1)
         self.assertFalse(self.set.contains(ent))
-        self.assert_(ent not in self.set)
+        self.assertTrue(ent not in self.set)
         self.assertEqual(self.set.getNumOfType(iBase.Type.all), 0)
         self.assertEqual(self.set.getNumOfTopo(iMesh.Topology.all), 0)
         self.assertEqual(len(self.set), 0)
 
         self.set.add(ent)
-        self.assert_(self.set.contains(ent))
-        self.assert_(ent in self.set)
+        self.assertTrue(self.set.contains(ent))
+        self.assertTrue(ent in self.set)
         self.assertEqual(self.set.getNumOfType(iBase.Type.all), 1)
         self.assertEqual(self.set.getNumOfTopo(iMesh.Topology.all), 1)
         self.assertEqual(len(self.set), 1)
 
         self.set.remove(ent)
         self.assertFalse(self.set.contains(ent))
-        self.assert_(ent not in self.set)
+        self.assertTrue(ent not in self.set)
         self.assertEqual(self.set.getNumOfType(iBase.Type.all), 0)
         self.assertEqual(self.set.getNumOfTopo(iMesh.Topology.all), 0)
         self.assertEqual(len(self.set), 0)
@@ -58,7 +56,7 @@ class TestEntSet(unittest.TestCase):
         self.assertEqual(len(self.set), 0)
 
         self.set.add(ents)
-        self.assert_(self.set.contains(ents).all())
+        self.assertTrue(self.set.contains(ents).all())
         self.assertEqual(self.set.getNumOfType(iBase.Type.all), 3)
         self.assertEqual(self.set.getNumOfTopo(iMesh.Topology.all), 3)
         self.assertEqual(len(self.set), 3)
@@ -71,17 +69,31 @@ class TestEntSet(unittest.TestCase):
 
     def testEntSet(self):
         sub = self.mesh.createEntSet(True)
+        subsub = self.mesh.createEntSet(True)
 
         self.assertFalse(self.set.contains(sub))
-        self.assert_(sub not in self.set)
+        self.assertTrue(sub not in self.set)
+        self.assertEqual(self.set.getNumEntSets(), 0)
+        self.assertEqual(len(self.set.getEntSets()), 0)
 
         self.set.add(sub)
-        self.assert_(self.set.contains(sub))
-        self.assert_(sub in self.set)
+        sub.add(subsub)
+
+        self.assertTrue(self.set.contains(sub))
+        self.assertTrue(sub in self.set)
+        self.assertEqual(self.set.getNumEntSets(), 2)
+        self.assertEqual(self.set.getNumEntSets(0), 1)
+        self.assertEqual(self.set.getNumEntSets(1), 2)
+
+        self.assertArraySorted(self.set.getEntSets(),
+                               iBase.Array([sub, subsub]))
+        self.assertArraySorted(self.set.getEntSets(0), iBase.Array([sub]))
+        self.assertArraySorted(self.set.getEntSets(1),
+                               iBase.Array([sub, subsub]))
 
         self.set.remove(sub)
         self.assertFalse(self.set.contains(sub))
-        self.assert_(sub not in self.set)
+        self.assertTrue(sub not in self.set)
 
         self.mesh.destroyEntSet(sub)
 
@@ -89,18 +101,18 @@ class TestEntSet(unittest.TestCase):
         sub = self.mesh.createEntSet(True)
         self.set.addChild(sub)
 
-        self.assert_(self.set.isChild(sub))
-        self.assertEqual(self.set.getNumChildren(1), 1)
-        self.assertEqual(sub.getNumParents(1),  1)
+        self.assertTrue(self.set.isChild(sub))
+        self.assertEqual(self.set.getNumChildren(), 1)
+        self.assertEqual(sub.getNumParents(), 1)
 
-        self.assertEqual(self.set.getChildren(1)[0], sub)
-        self.assertEqual(sub.getParents(1)[0], self.set)
+        self.assertOut(self.set.getChildren, ex=iBase.Array([sub]))
+        self.assertOut(sub.getParents, ex=iBase.Array([self.set]))
 
         self.set.removeChild(sub)
 
-        self.assert_(not self.set.isChild(sub))
-        self.assertEqual(self.set.getNumChildren(1), 0)
-        self.assertEqual(sub.getNumParents(1),  0)
+        self.assertTrue(not self.set.isChild(sub))
+        self.assertEqual(self.set.getNumChildren(), 0)
+        self.assertEqual(sub.getNumParents(),  0)
 
     def testSubtract(self):
         set2 = self.mesh.createEntSet(True)
@@ -145,6 +157,3 @@ class TestEntSet(unittest.TestCase):
         union = self.set.union(set2)
         self.assertTrue(union.contains(ents[0]))
         self.assertTrue(union.contains(ents[1]))
-
-if __name__ == '__main__':
-    unittest.main()
